@@ -15,6 +15,7 @@ package Spreadsheet::Read;
  my $book  = ReadData ("test.xls");
  my $book  = ReadData ("test.xlsx");
  my $book  = ReadData ("test.xlsm");
+ my $book  = ReadData ("test.gnumeric");
  my $book  = ReadData ($fh, parser => "xls");
 
  Spreadsheet::Read::add ($book, "sheet.csv");
@@ -37,7 +38,7 @@ use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = "0.85";
+our $VERSION = "0.86";
 sub  Version { $VERSION }
 
 use Carp;
@@ -51,27 +52,28 @@ use File::Temp   qw( );
 use Data::Dumper;
 
 my @parsers = (
-    [ csv  => "Text::CSV_XS",				"0.71"		],
-    [ csv  => "Text::CSV_PP",				"1.17"		],
-    [ csv  => "Text::CSV",				"1.17"		],
-    [ ods  => "Spreadsheet::ParseODS",			"0.26"		],
-    [ ods  => "Spreadsheet::ReadSXC",			"0.26"		],
-    [ sxc  => "Spreadsheet::ParseODS",			"0.26"		],
-    [ sxc  => "Spreadsheet::ReadSXC",			"0.26"		],
-    [ xls  => "Spreadsheet::ParseExcel",		"0.34"		],
-    [ xlsx => "Spreadsheet::ParseXLSX",			"0.24"		],
-    [ xlsm => "Spreadsheet::ParseXLSX",			"0.24"		],
-    [ xlsx => "Spreadsheet::XLSX",			"0.13"		],
-#   [ prl  => "Spreadsheet::Perl",			""		],
-    [ sc   => "Spreadsheet::Read",			"0.01"		],
+    [ csv	=> "Text::CSV_XS",			"0.71"		],
+    [ csv	=> "Text::CSV_PP",			"1.17"		],
+    [ csv	=> "Text::CSV",				"1.17"		],
+    [ ods	=> "Spreadsheet::ParseODS",		"0.26"		],
+    [ ods	=> "Spreadsheet::ReadSXC",		"0.26"		],
+    [ sxc	=> "Spreadsheet::ParseODS",		"0.26"		],
+    [ sxc	=> "Spreadsheet::ReadSXC",		"0.26"		],
+    [ xls	=> "Spreadsheet::ParseExcel",		"0.34"		],
+    [ xlsx	=> "Spreadsheet::ParseXLSX",		"0.24"		],
+    [ xlsm	=> "Spreadsheet::ParseXLSX",		"0.24"		],
+    [ xlsx	=> "Spreadsheet::XLSX",			"0.13"		],
+#   [ prl	=> "Spreadsheet::Perl",			""		],
+    [ sc	=> "Spreadsheet::Read",			"0.01"		],
+    [ gnumeric	=> "Spreadsheet::ReadGnumeric",		"0.1"		],
 
-    [ zzz1 => "Z10::Just::For::Testing",		"1.23"		],
-    [ zzz2 => "Z20::Just::For::Testing",		""		],
-    [ zzz3 => "Z30::Just::For::Testing",		"1.00"		],
+    [ zzz1	=> "Z10::Just::For::Testing",		"1.23"		],
+    [ zzz2	=> "Z20::Just::For::Testing",		""		],
+    [ zzz3	=> "Z30::Just::For::Testing",		"1.00"		],
 
     # Helper modules
-    [ ios  => "IO::Scalar",				""		],
-    [ dmp  => "Data::Peek",				""		],
+    [ ios	=> "IO::Scalar",				""		],
+    [ dmp	=> "Data::Peek",				""		],
     );
 my %can = ( supports => { map { $_->[1] => $_->[2] } @parsers });
 foreach my $p (@parsers) {
@@ -454,6 +456,34 @@ sub _missing_parser {
     "No parser for $type found$suggest\n";
     } # _missing_parser
 
+sub _txt_is_xml {
+    # Return true if $txt is gzipped or contains XML.  If we are also passed
+    # $ns_uri_of_interest, $txt must contain it in the first 1000 or so
+    # characters (but we try to search quickly rather than precisely).
+    my ($txt, $ns_uri_of_interest) = @_;
+
+    ref $txt and return; # Can't tell (unless we assume the stream is seekable).
+
+    if ($txt =~ m/\A\037\213/) {
+	# Literal gzipped string (/usr/share/misc/magic).  [this is a hack that
+	# works only because Gnumeric is the only format that uses gzip.  --
+	# rgr, 13-Jan-2023]
+	return 1;
+	}
+
+    if ($txt =~ m/\A<\?xml/) {
+	$ns_uri_of_interest or return 1;
+	$ns_uri_of_interest =~ s/([^\w\d])/\\$1/g;
+	my $prefix = length ($txt) > 10000 ? substr $txt, 0, 1000 : $txt;
+	return $prefix =~ m/xmlns:\w+=.$ns_uri_of_interest/;
+	}
+
+    $txt =~ m/\n/		and return; # safeguard for older perl versions
+    open my $in, "<", $txt	or  return;
+    read $in, my $block, 1000	or  return;
+    return _txt_is_xml ($block, $ns_uri_of_interest);
+    } # _txt_is_xml
+
 sub ReadData {
     my $txt = shift	or  return;
 
@@ -1204,6 +1234,14 @@ sub ReadData {
 	return _clipsheets \%opt, [ @data ];
 	}
 
+    if ($opt{parser} ? _parser ($opt{parser}) eq "gnumeric"
+		     : _txt_is_xml ($txt, "http://www.gnumeric.org/v10.dtd")) {
+	$can{gnumeric} or croak _missing_parser ("gnumeric");
+
+	my $gnm = $can{gnumeric}->new (%parser_opts, gzipped_p => $opt{gzipped_p});
+	return _clipsheets \%opt, $gnm->parse ($txt);
+	}
+
     if ($opt{parser} ? _parser ($opt{parser}) eq "sxc"
 		     : ($txt =~ m/^<\?xml/ or -f $txt)) {
 	$can{sxc} or croak _missing_parser ("SXC");
@@ -1214,7 +1252,7 @@ sub ReadData {
 	my $using = "using $can{sxc}-" . $can{sxc}->VERSION;
 	my $sxc_options = { %parser_opts, OrderBySheet => 1 }; # New interface 0.20 and up
 	my $sxc;
-	   if ($txt =~ m/\.(sxc|ods)$/i) {
+	if ($txt =~ m/\.(sxc|ods)$/i) {
 	    $debug and print STDERR "Opening \U$1\E $txt $using\n";
 	    $debug and print STDERR __FILE__, "#", __LINE__, "\n";
 	    $sxc = Spreadsheet::ReadSXC::read_sxc      ($txt, $sxc_options) or return;
@@ -2533,12 +2571,6 @@ Under investigation:
 
 =over 2
 
-=item Gnumeric (.gnumeric)
-
-I have seen no existing CPAN module yet.
-
-It is gzip'ed XML
-
 =item Kspread (.ksp)
 
 Now knows as Calligra Sheets.
@@ -2605,6 +2637,12 @@ successor of  L<Spreadsheet::ReadSXC|https://metacpan.org/release/Spreadsheet-Re
 L<Spreadsheet::ReadSXC|https://metacpan.org/release/Spreadsheet-ReadSXC> is a
 parser for OpenOffice/LibreOffice (.sxc and .ods) spreadsheet files.
 
+=item Spreadsheet::ReadGnumeric
+
+L<Spreadsheet::ReadGnumeric|https://metacpan.org/release/Spreadsheet-ReadGnumeric>
+is a parser for L<Gnumeric|http://www.gnumeric.org/> (.gnumeric) spreadsheet
+files.
+
 =item Spreadsheet::BasicRead
 
 See L<Spreadsheet::BasicRead|https://metacpan.org/release/Spreadsheet-BasicRead>
